Package: sicegar
Type: Package
Title: Analysis of Single-Cell Viral Growth Curves
Version: 0.3.0
Authors@R: c( 
    person(
      given = "Johanna",
      family = "Hardin",
      role = c("aut", "cre"),
      email = "jo.hardin@pomona.edu",
      comment = c(ORCID = "0000-0001-6251-1955")
    ),
    person(
      given = "Samuel",
      family = "Butler",
      role = c("aut"),
      email = "swbe2022@mymail.pomona.edu"
    ),
    person(
      given = "Phineus",
      family = "Choi",
      role = c("aut"),
      email = "pchm2023@mymail.pomona.edu"
    ),
    person(
      given = "Thomas",
      family = "Matheis",
      role = c("aut"),
      email = "tomp2024@mymail.pomona.edu"
    ),
    person(
      given = "Mira",
      family = "Terdiman",
      role = c("aut"),
      email = "mterdiman@berkeley.edu"
    ),
    person(
      given = "M. Umut",
      family = "Caglar",
      role = c("aut"),
      email = "umut.caglar@gmail.com"
    ),
    person(
      given = "Claus O.",
      family = "Wilke",
      role = c("aut"),
      email = "wilke@austin.utexas.edu",
      comment = c(ORCID = "0000-0002-7470-9261")
    )
  )  
Description: 
    Aims to quantify time intensity data by using sigmoidal and
    double sigmoidal curves. It fits straight lines, sigmoidal, 
    and double sigmoidal curves on to time vs intensity data. 
    Then all the fits are used to make decision on which model 
    best describes the data. This method was first developed 
    in the context of single-cell viral growth analysis (for
    details, see Caglar et al. (2018) <doi:10.7717/peerj.4251>),
    and the package name stands for "SIngle CEll Growth Analysis in R".
URL: https://github.com/wilkelab/sicegar/,
        https://hardin47.github.io/sicegar/
Imports: minpack.lm, fBasics, ggplot2, stats, dplyr
License: GPL-2 | GPL-3
Suggests: covr, cowplot, testthat, knitr, rmarkdown
VignetteBuilder: knitr
BugReports: https://github.com/hardin47/sicegar/issues
Collate: 'globals.R' 'categorize.R' 'categorize_h0.R' 'mainFunctions.R'
        'multipleFitFunction.R' 'multipleFitFunction_h0.R'
        'sigmoidalFitFunctions.R' 'sigmoidalFitFunctions_h0.R'
        'doublesigmoidalFitFunctions.R'
        'doublesigmoidalFitFunctions_h0.R' 'normalizationFunction.R'
        'sicegar.R' 'dataInputCheck.R' 'parameterCalculation.R'
        'parameterCalculation_h0.R' 'figureGeneration.R'
RoxygenNote: 7.3.2
Encoding: UTF-8
NeedsCompilation: no
Packaged: 2025-11-15 16:41:22 UTC; jsh04747
Author: Johanna Hardin [aut, cre] (ORCID:
    <https://orcid.org/0000-0001-6251-1955>),
  Samuel Butler [aut],
  Phineus Choi [aut],
  Thomas Matheis [aut],
  Mira Terdiman [aut],
  M. Umut Caglar [aut],
  Claus O. Wilke [aut] (ORCID: <https://orcid.org/0000-0002-7470-9261>)
Maintainer: Johanna Hardin <jo.hardin@pomona.edu>
Repository: CRAN
Date/Publication: 2025-11-15 22:40:02 UTC
Built: R 4.6.0; ; 2026-04-29 08:01:26 UTC; unix
