# Generated by roxygen2: do not edit by hand

export(categorize)
export(categorize_h0)
export(dataCheck)
export(doublesigmoidalFitFormula)
export(doublesigmoidalFitFormula_h0)
export(doublesigmoidalFitFunction)
export(doublesigmoidalFitFunction_h0)
export(figureModelCurves)
export(fitAndCategorize)
export(multipleFitFunction)
export(multipleFitFunction_h0)
export(normalizeData)
export(parameterCalculation)
export(parameterCalculation_h0)
export(preCategorize)
export(sameSourceDataCheck)
export(sigmoidalFitFormula)
export(sigmoidalFitFormula_h0)
export(sigmoidalFitFunction)
export(sigmoidalFitFunction_h0)
export(unnormalizeData)
